if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/ab3b9d87-790d-4696-7077-b75fd24559a2/volume/pymongo_1607369026503/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt